@@ -279,6 +279,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 elif ylabel == "W" and "dB" in yunit:
                     ylabel = "SWL"
 
+            # Keep only one decimal in dB case
+            if "dB" in yunit:
+                Y_str = format(float(Y_str), ".1f")
+
             label = (
                 xlabel
                 + " = "
@@ -308,7 +312,13 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 elif zlabel == "W" and "dB" in zunit:
                     zlabel = "SWL"
 
-                label += sep + zlabel + " = " + format(z, ".4g") + " " + zunit
+                # Keep only one decimal in dB case
+                if "dB" in yunit:
+                    Z_str = format(z, ".1f")
+                else:
+                    Z_str = format(z, ".4g")
+
+                label += sep + zlabel + " = " + Z_str + " " + zunit
 
             # Remove latex marks for top right corner
             if sep == ", ":
@@ -504,15 +514,29 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 for param in PARAM_3D:
                     if param in plot_arg_dict_2D:
                         del plot_arg_dict_2D[param]
-                self.data.plot_2D_Data(
-                    *[*axes_selected, *data_selection],
-                    **plot_arg_dict_2D,
-                    unit=output_range["unit"],
-                    fig=self.fig,
-                    ax=self.ax,
-                    y_min=output_range["min"],
-                    y_max=output_range["max"],
-                )
+                if (
+                    "type_plot" in plot_arg_dict_2D
+                    and plot_arg_dict_2D["type_plot"] == "quiver"
+                ):
+                    self.plot_2D_Data(
+                        *[*axes_selected, *data_selection],
+                        **plot_arg_dict_2D,
+                        unit=output_range["unit"],
+                        fig=self.fig,
+                        ax=self.ax,
+                        y_min=output_range["min"],
+                        y_max=output_range["max"],
+                    )
+                else:
+                    self.data.plot_2D_Data(
+                        *[*axes_selected, *data_selection],
+                        **plot_arg_dict_2D,
+                        unit=output_range["unit"],
+                        fig=self.fig,
+                        ax=self.ax,
+                        y_min=output_range["min"],
+                        y_max=output_range["max"],
+                    )
 
             elif len(axes_selected) == 2:
                 plot_arg_dict_3D = self.plot_arg_dict.copy()
@@ -542,7 +566,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         data,
         unit=None,
         axes_request_list=None,
-        plot_arg_dict=None,
+        plot_arg_dict=dict(),
         is_keep_config=False,
         frozen_type=0,
     ):
