@@ -1,4 +1,4 @@
-from numpy import array
+from numpy import array, argsort
 
 from importlib import import_module
 
@@ -50,6 +50,16 @@ def get_axis(self, axis, is_real):
             if self.indices[0] == ":":
                 self.values = values
                 self.indices = list(range(len(values)))
+            elif isinstance(self.indices[0], str):  # N largest
+                self.extension = "list"
+                N = int(self.indices[0])
+                # Sort values
+                if hasattr(axis, "sort_indices") and axis.sort_indices is not None:
+                    self.indices = axis.sort_indices[:N]
+                    self.values = values[self.indices]
+                else:
+                    self.indices = argsort(values)[::-1][:N].tolist()
+                    self.values = values[self.indices]
             else:
                 self.values = values[self.indices]
                 self.extension = "list"
@@ -217,6 +227,13 @@ def get_axis(self, axis, is_real):
             else:
                 self.values = values
         if self.indices is not None:
+            if isinstance(self.indices[0], str):  # N largest
+                N = int(self.indices[0])
+                # Sort values
+                if hasattr(axis, "sort_indices") and axis.sort_indices is not None:
+                    self.indices = axis.sort_indices[:N]
+                else:
+                    self.indices = argsort(values)[::-1][:N].tolist()
             self.values = values[self.indices]
             if self.extension in operation_list:
                 self.indices = None
